@@ -2,8 +2,9 @@ amelia2mitml.list <- function(x){
 # convert amelia to mitml.list
 
   out <- unname(x$imputations)
-  class(out) <- c("mitml.list","list")
-  out
+  class(out) <- c("mitml.list", "list")
+
+  return(out)
 
 }
 
